"""Mach-O/ARM64 analyzer"""

__version__ = "13.0.5"
__author__ = "Data Theorem"
__url__ = "https://github.com/datatheorem/strongarm"
